@@ -54,30 +54,38 @@ predict.simple_ensemble <-
         message("as no 'threshold' was defined, a default of 0.5 will be used")
         class_thresh <- 0.5
       }
-
-      # check that we have an entry for this calibration
-      ref_calib_tb <- attr(object, "class_thresholds")
-      # give up immediately if ref_calib_tb is null
-      if (is.null(ref_calib_tb)) {
-        stop(
-          "this model needs to be first calibrated before classes can be produced\n",
-          "use 'calib_class_thresh()' first"
-        )
-      } else if (!any(unlist(lapply(ref_calib_tb %>% dplyr::pull("metric_thresh"), identical, metric_thresh)) &
-        unlist(lapply(ref_calib_tb %>% dplyr::pull("class_thresh"), identical, class_thresh)))) {
-        stop(
-          "this model needs to be first calibrated before classes can be produced\n",
-          "use 'calib_class_thresh()' first"
-        )
+      
+      # if the class_threshold is not numeric, then we need to ensure the model has been calibrated for the right metric
+      if (!is.numeric(class_thresh)){
+        # check that we have an entry for this calibration
+        ref_calib_tb <- attr(object, "class_thresholds")
+        # give up immediately if ref_calib_tb is null
+        if (is.null(ref_calib_tb)) {
+          stop(
+            "this model needs to be first calibrated before classes can be produced\n",
+            "use 'calib_class_thresh()' first"
+          )
+        } else if (!any(unlist(lapply(ref_calib_tb %>% dplyr::pull("metric_thresh"), identical, metric_thresh)) &
+                        unlist(lapply(ref_calib_tb %>% dplyr::pull("class_thresh"), identical, class_thresh)))) {
+          stop(
+            "this model needs to be first calibrated before classes can be produced\n",
+            "use 'calib_class_thresh()' first"
+          )
+        }
+        
+        
+        # subset the calibration thresholds
+        ref_calib_tb <- ref_calib_tb[
+          (unlist(lapply(ref_calib_tb %>% dplyr::pull("metric_thresh"), identical, metric_thresh)) &
+             unlist(lapply(ref_calib_tb %>% dplyr::pull("class_thresh"), identical, class_thresh))) &
+            ref_calib_tb$fun %in% fun,
+        ]       
+      } else { #if class_thresh is numeric, fake a calib table
+        ref_calib_tb <- tibble::tibble(fun = fun,
+                               optim_value = rep(class_thresh, length(fun)))
       }
 
-
-      # subset the calibration thresholds
-      ref_calib_tb <- ref_calib_tb[
-        (unlist(lapply(ref_calib_tb %>% dplyr::pull("metric_thresh"), identical, metric_thresh)) &
-          unlist(lapply(ref_calib_tb %>% dplyr::pull("class_thresh"), identical, class_thresh))) &
-          ref_calib_tb$fun %in% fun,
-      ]
+      #browser()
       class_levels <- levels(workflows::extract_mold((object$workflow[[1]]))$outcome %>% dplyr::pull(1))
     }
 
